# -*- coding: utf-8 -*-
# WARNING: Autogenerated code. Do not edit manually.
import typing as t
from decimal import Decimal
from mcrpc.responses import *


class RpcClient:

    def __init__(self, host: str, port: str, user: str, pwd: str, use_ssl: bool=False):
        self.host: str
        self.port: str
        self.user: str
        self.pwd: str
        self.use_ssl: bool

    def _url(self) -> str: ...

    def _call(self, method: str, *args): ...

$methods

